summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_coreboot.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-06-09 17:13:27 +0200
committerHolger Levsen <holger@layer-acht.org>2015-06-09 17:13:27 +0200
commit51d31fe3b281c0a47003c3487e928adbc13eb42f (patch)
tree6acdf555a3ca93e22ed0defbf30a3c90906d8557 /bin/reproducible_coreboot.sh
parent344126d92614d04980a8f1b8ce4f4ec1d4956c5c (diff)
downloadjenkins.debian.net-51d31fe3b281c0a47003c3487e928adbc13eb42f.tar.xz
reproducible coreboot: sharedutils is another build result to ignore
Diffstat (limited to 'bin/reproducible_coreboot.sh')
-rwxr-xr-xbin/reproducible_coreboot.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_coreboot.sh b/bin/reproducible_coreboot.sh
index 5cd23f8d..6ce5baa3 100755
--- a/bin/reproducible_coreboot.sh
+++ b/bin/reproducible_coreboot.sh
@@ -123,8 +123,8 @@ nice ionice -c 3 \
cd coreboot-builds
for i in * ; do
- # abuild is a build result but not the result we are looking for...
- if [ "$i" != "abuild" ] ; then
+ # abuild and sharedutils are build results but not the results we are looking for...
+ if [ "$i" != "abuild" ] && [ "$i" != "sharedutils" ] ; then
mkdir $TMPDIR/b1/$i
if [ -f $i/coreboot.rom ] ; then
cp -p $i/coreboot.rom $TMPDIR/b1/$i/